'use client'
import React from 'react'
import { Button } from "@heroui/react";
import { Image } from "@heroui/image";
import { FaRegCheckCircle } from "react-icons/fa";
import { CgMoreO } from "react-icons/cg";
import { IoMailOutline } from "react-icons/io5";
import Footer from '@/components/Footer';
import Link from 'next/link';

const page = () => {
    return (
        <>
            <main className='mx-3 xl:mx-20 mt-3 xl:mt-10 mb-10 lg:mb-28'>
                {/* HERO SECTION */}
                <div
                    className="flex flex-col justify-center items-start h-[12rem] p-5 md:p-10 rounded-3xl bg-cover bg-center bg-fixed"
                    style={{
                        backgroundImage: "url('/old-hero.jpg')",
                    }}
                >
                    <p className='text-white text-sm md:text-medium font-medium'><Link className='hover:underline' href={'/'}>HOME</Link> / <Link href={'/about'} className="text-yellow-500 hover:underline">ABOUT</Link></p>
                    <p className="text-white font-semibold text-4xl lg:text-5xl mt-3">C&C General Contructors</p>
                </div>
                {/* HERO SECTION */}

                {/* SECTION 1 */}
                <div className='mt-6 lg:mt-28 flex md:flex-row gap-5 md:gap-0 flex-col'>

                    <div className='w-full md:w-1/2'>
                        <p className='text-2xl md:text-4xl font-semibold mt-3 text-slate-800'>Incurred substantial <span className="text-red-500">damage</span> to your roof that requires immediate assistance?</p>
                        <p className='text-medium md:text-xl mt-5 md:mt-8 text-gray-600 leading-8'>C&C General Contractors is a located right here in Carrollton, Texas, and can respond quickly to help you prevent any future water damage.</p>

                    </div>
                    <div className='w-full md:w-1/2'>
                        <Image
                            isBlurred
                            src='/about-1.jpg'
                            alt='img'
                            className='w-3/4 mx-auto'
                        />
                    </div>
                </div>
                {/* SECTION 1 */}
                <hr className='mt-16 mb-10' />

                {/* SECTION 2 */}
                <div>
                    <p className='text-2xl md:text-4xl font-semibold mt-3 text-slate-800'>Why you should stay local</p>
                    <p className='text-medium md:text-xl mt-5 md:mt-8 text-gray-600 leading-8'>Generally after a large hail storm, neighborhoods will be flooded with roofing salesmen, most likely from out of town, who will promise you this and that and then be gone. If you choose to work with C&C General Contractors, we can also give you a free estimate and work with your insurance company.</p>
                    <p className='text-medium md:text-xl mt-2 font-light text-gray-600 leading-8'>The difference? We are here, and we will be here not just from the beginning to the end, but long after as well. This means, any future potential issues will be handled quickly, meeting and exceeding your expectations. </p>
                </div>
                {/* SECTION 2 */}
                <hr className='my-10' />

                {/* SECTION 3 */}
                <div>
                    <p className='text-2xl md:text-4xl font-semibold mt-3 text-slate-800'>Why you should choose C&C General Contructors</p>
                    <div className="lists mt-5 md:mt-8 flex ml-3 md:ml-5 lg:ml-10 flex-col gap-3">
                        <p className='flex items-start lg:items-center gap-4 text-lg md:text-xl'><FaRegCheckCircle className='text-yellow-500 hidden lg:block' /> <span className="text-yellow-500 lg:hidden">-</span> We are not a large company, which means we do not have the same overhead that larger companies in the area may have.</p>
                        <p className='flex items-start lg:items-center gap-4 text-lg md:text-xl'><FaRegCheckCircle className='text-yellow-500 hidden lg:block' /> <span className="text-yellow-500 lg:hidden">-</span> We provide before, during and after photos of our work.</p>
                        <div className='flex items-start gap-4'>
                            <FaRegCheckCircle className='text-yellow-500 text-[1.8rem] hidden lg:block' />
                            <span className="text-yellow-500 lg:hidden">-</span>
                            <p className='text-lg md:text-xl'>We do not cut any corners, such as putting new felt over old or using existing felt and not installing new felt at all. These type of corner-cutting practices void manufacturer warranty.</p>
                        </div>
                        <p className='flex items-start lg:items-center gap-4 text-lg md:text-xl'><FaRegCheckCircle className='text-yellow-500 hidden lg:block' /> <span className="text-yellow-500 lg:hidden">-</span> We deal direct with your insurance company once the claim is filled</p>
                        <p className='flex items-start lg:items-center gap-4 text-lg md:text-xl'><FaRegCheckCircle className='text-yellow-500 hidden lg:block' /> <span className="text-yellow-500 lg:hidden">-</span> We respond to any issues immediately</p>
                        <div className='flex items-start gap-4'>
                            <FaRegCheckCircle className='text-yellow-500 text-4xl hidden lg:block' />
                            <span className="text-yellow-500 lg:hidden">-</span>
                            <p className='text-lg md:text-xl'>We will inspect your property to verify scope, analyze what all your insurance estimate includes and make necessary corrections for your insurance company's approval. Then we will complete the restoration the way it should be.</p>
                        </div>
                    </div>
                </div>
                {/* SECTION 3 */}

                {/* LETS START SECTION */}
                <div className="mt-6 lg:mt-28 flex flex-col md:flex-row rounded-3xl bg-green-100/30">

                    <div className='w-full md:w-1/2 p-3 md:p-10'>
                        <p className='text-4xl lg:text-5xl font-semibold mt-3 text-slate-800'>Let's build something great <span className="text-yellow-500">together</span></p>
                        <p className='text-lg lg:text-xl mt-8 text-gray-600 leading-8'>Don’t wait any longer to bring your construction dreams to life. Partner with C&CGC and experience unparalleled service and quality.</p>
                        <Button as={Link} href='/contact' className='mt-5 lg:mt-10' variant='shadow' size='md' color='warning'>Contact Us <IoMailOutline /></Button>
                    </div>
                    <div className='w-full md:w-1/2 flex items-end'>
                        <Image
                            isBlurred
                            src='/cta.png'
                            alt='cta'
                            className='w-3/4 mx-auto'
                        />
                    </div>
                </div>
                {/* LETS START SECTION */}
            </main>
            <Footer />
        </>
    )
}

export default page